summaryrefslogtreecommitdiffstats
path: root/src/citra/default_ini.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/citra/default_ini.h')
-rw-r--r--src/citra/default_ini.h25
1 files changed, 15 insertions, 10 deletions
diff --git a/src/citra/default_ini.h b/src/citra/default_ini.h
index 618f1aeaa..435ba6f00 100644
--- a/src/citra/default_ini.h
+++ b/src/citra/default_ini.h
@@ -51,14 +51,21 @@ use_hw_renderer =
# 0: Interpreter (slow), 1 (default): JIT (fast)
use_shader_jit =
-# Whether to use native 3DS screen resolution or to scale rendering resolution to the displayed screen size.
-# 0 (default): Native, 1: Scaled
-use_scaled_resolution =
+# Resolution scale factor
+# 0: Auto (scales resolution to window size), 1: Native 3DS screen resolution, Otherwise a scale
+# factor for the 3DS resolution
+resolution_factor =
# Whether to enable V-Sync (caps the framerate at 60FPS) or not.
# 0 (default): Off, 1: On
use_vsync =
+# The clear color for the renderer. What shows up on the sides of the bottom screen.
+# Must be in range of 0.0-1.0. Defaults to 1.0 for all.
+bg_red =
+bg_blue =
+bg_green =
+
[Layout]
# Layout for the screen inside the render window.
# 0 (default): Default Top Bottom Screen, 1: Single Screen Only, 2: Large Screen Small Screen
@@ -73,12 +80,6 @@ toggle_framelimit =
# 0 (default): Top Screen is prominent, 1: Bottom Screen is prominent
swap_screen =
-# The clear color for the renderer. What shows up on the sides of the bottom screen.
-# Must be in range of 0.0-1.0. Defaults to 1.0 for all.
-bg_red =
-bg_blue =
-bg_green =
-
[Audio]
# Which audio output engine to use.
# auto (default): Auto-select, null: No audio output, sdl2: SDL2 (if available)
@@ -90,6 +91,10 @@ output_engine =
# 0: No, 1 (default): Yes
enable_audio_stretching =
+# Which audio device to use.
+# auto (default): Auto-select
+output_device =
+
[Data Storage]
# Whether to create a virtual SD card.
# 1 (default): Yes, 0: No
@@ -101,7 +106,7 @@ use_virtual_sd =
is_new_3ds =
# The system region that Citra will use during emulation
-# 0: Japan, 1: USA (default), 2: Europe, 3: Australia, 4: China, 5: Korea, 6: Taiwan
+# -1: Auto-select (default), 0: Japan, 1: USA, 2: Europe, 3: Australia, 4: China, 5: Korea, 6: Taiwan
region_value =
[Camera]